@@ -7,8 +7,9 @@ students.
 
 import logging
 
-from pythonanywhere.api.students_api import StudentsAPI
-from pythonanywhere.snakesay import snakesay
+from snakesay import snakesay
+
+from pythonanywhere_core.students import StudentsAPI
 
 logger = logging.getLogger("pythonanywhere")
 
