@@ -48,6 +48,43 @@ def test_main_subcommand_without_args_prints_help():
     assert "Show this message and exit." in result.stdout
 
 
+def test_list_webapps(mocker):
+    mock_webapp_class = mocker.patch("cli.webapp.Webapp")
+    mock_webapp_class.list_webapps.return_value = [
+        {"domain_name": "example1.com", "python_version": "python38"},
+        {"domain_name": "example2.pythonanywhere.com", "python_version": "python311"},
+    ]
+
+    result = runner.invoke(app, ["list"])
+
+    assert result.exit_code == 0
+    mock_webapp_class.list_webapps.assert_called_once()
+    assert "example1.com" in result.stdout
+    assert "example2.pythonanywhere.com" in result.stdout
+    assert "python38" not in result.stdout
+
+
+def test_get_webapp(mock_webapp, domain_name):
+    mock_webapp.return_value.get.return_value = {
+        "domain_name": domain_name,
+        "python_version": "python38",
+        "source_directory": "/home/user/mysite/",
+        "virtualenv_path": "/home/user/.virtualenvs/mysite/",
+        "enabled": True,
+    }
+
+    result = runner.invoke(app, ["get", "-d", domain_name])
+
+    assert result.exit_code == 0
+    mock_webapp.assert_called_once_with(domain_name)
+    mock_webapp.return_value.get.assert_called_once()
+    assert domain_name in result.stdout
+    assert "python38" in result.stdout
+    assert "/home/user/mysite/" in result.stdout
+    assert "Domain" in result.stdout
+    assert "Python version" in result.stdout
+
+
 def test_create_calls_all_stuff_in_right_order(mocker):
     mock_project = mocker.patch("cli.webapp.Project")
 
@@ -69,7 +106,7 @@ def test_create_calls_all_stuff_in_right_order(mocker):
         call.virtualenv.create(nuke=True),
         call.create_webapp(nuke=True),
         call.add_static_file_mappings(),
-        call.webapp.reload(),
+        call.reload_webapp(),
     ]
     assert "All done! Your site is now live at https://www.domain.com" in result.stdout
     assert (
@@ -78,6 +115,59 @@ def test_create_calls_all_stuff_in_right_order(mocker):
     )
 
 
+def test_reload(mock_webapp, domain_name):
+    result = runner.invoke(app, ["reload", "-d", domain_name])
+
+    assert f"{domain_name} has been reloaded" in result.stdout
+    mock_webapp.assert_called_once_with(domain_name)
+    assert mock_webapp.return_value.method_calls == [call.reload()]
+
+
+def test_install_ssl_with_default_reload(mock_webapp, domain_name, file_with_content):
+    mock_webapp.return_value.get_ssl_info.return_value = {
+        "not_after": datetime(2018, 8, 24, 17, 16, 23, tzinfo=tzutc())
+    }
+    certificate = "certificate"
+    certificate_file = file_with_content(certificate)
+    private_key = "private_key"
+    private_key_file = file_with_content(private_key)
+
+    result = runner.invoke(
+        app,
+        ["install-ssl", domain_name, certificate_file, private_key_file],
+    )
+
+    mock_webapp.assert_called_once_with(domain_name)
+    mock_webapp.return_value.set_ssl.assert_called_once_with(certificate, private_key)
+    mock_webapp.return_value.reload.assert_called_once()
+    assert f"for {domain_name}" in result.stdout
+    assert "2018-08-24," in result.stdout
+
+
+def test_install_ssl_with_reload_suppressed(
+    mock_webapp, domain_name, file_with_content
+):
+    certificate = "certificate"
+    certificate_file = file_with_content(certificate)
+    private_key = "private_key"
+    private_key_file = file_with_content(private_key)
+
+    runner.invoke(
+        app,
+        [
+            "install-ssl",
+            domain_name,
+            certificate_file,
+            private_key_file,
+            "--suppress-reload",
+        ],
+    )
+
+    mock_webapp.assert_called_once_with(domain_name)
+    mock_webapp.return_value.set_ssl.assert_called_once_with(certificate, private_key)
+    mock_webapp.return_value.reload.assert_not_called()
+
+
 def test_delete_all_logs(mock_webapp, domain_name):
     result = runner.invoke(
         app,
@@ -154,54 +244,10 @@ def test_validates_log_number(mock_webapp):
     assert "log_index has to be 0 for current" in result.stdout
 
 
-def test_install_ssl_with_default_reload(mock_webapp, domain_name, file_with_content):
-    mock_webapp.return_value.get_ssl_info.return_value = {
-        "not_after": datetime(2018, 8, 24, 17, 16, 23, tzinfo=tzutc())
-    }
-    certificate = "certificate"
-    certificate_file = file_with_content(certificate)
-    private_key = "private_key"
-    private_key_file = file_with_content(private_key)
-
-    result = runner.invoke(
-        app,
-        ["install-ssl", domain_name, certificate_file, private_key_file],
-    )
+def test_delete_webapp(mock_webapp, domain_name):
+    result = runner.invoke(app, ["delete", "-d", domain_name])
 
+    assert result.exit_code == 0
     mock_webapp.assert_called_once_with(domain_name)
-    mock_webapp.return_value.set_ssl.assert_called_once_with(certificate, private_key)
-    mock_webapp.return_value.reload.assert_called_once()
-    assert f"for {domain_name}" in result.stdout
-    assert "2018-08-24," in result.stdout
-
-
-def test_install_ssl_with_reload_suppressed(
-    mock_webapp, domain_name, file_with_content
-):
-    certificate = "certificate"
-    certificate_file = file_with_content(certificate)
-    private_key = "private_key"
-    private_key_file = file_with_content(private_key)
-
-    runner.invoke(
-        app,
-        [
-            "install-ssl",
-            domain_name,
-            certificate_file,
-            private_key_file,
-            "--suppress-reload",
-        ],
-    )
-
-    mock_webapp.assert_called_once_with(domain_name)
-    mock_webapp.return_value.set_ssl.assert_called_once_with(certificate, private_key)
-    mock_webapp.return_value.reload.assert_not_called()
-
-
-def test_reload(mock_webapp, domain_name):
-    result = runner.invoke(app, ["reload", "-d", domain_name])
-
-    assert f"{domain_name} has been reloaded" in result.stdout
-    mock_webapp.assert_called_once_with(domain_name)
-    assert mock_webapp.return_value.method_calls == [call.reload()]
+    mock_webapp.return_value.delete.assert_called_once()
+    assert f"{domain_name} has been deleted" in result.stdout
